﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.Win32;
using System.Collections.ObjectModel;
using System.Diagnostics;
using System.Speech.Synthesis;

namespace SampleApp
{
    /// <summary>
    /// MainWindow.xaml 的交互逻辑
    /// </summary>
    public partial class MainWindow : Window
    {
        OpenFileDialog openFileDlg = null;
        /// <summary>
        /// 指示是否正在计算
        /// </summary>
        bool isRunning = false;

        ObservableCollection<PhotoData> photolist = null;
        public MainWindow()
        {
            InitializeComponent();
            photolist = new ObservableCollection<PhotoData>();
            Binding srcbinding = new Binding();
            srcbinding.Source = photolist;
            srcbinding.IsAsync = true;
            srcbinding.Mode = BindingMode.OneWay;
            lb.SetBinding(ListBox.ItemsSourceProperty, srcbinding);
            openFileDlg = new OpenFileDialog();
            openFileDlg.Filter = "照片文件|*.jpg;*.jpeg";
            openFileDlg.Title = "选择照片";
            openFileDlg.Multiselect = true;
        }


        private void OnOpen(object sender, RoutedEventArgs e)
        {
            if (isRunning)
            {
                MessageBox.Show("有一个计算任务正在运行，请等待计算完成后再试。");
                return;
            }
            bool? b = openFileDlg.ShowDialog();
            if (b == true)
            {
                string[] files = openFileDlg.FileNames;
                // 开始计算
                photolist.Clear();
                isRunning = true;
                foreach (string f in files)
                {
                    try
                    {
                        PhotoData data = new PhotoData(f);
                        photolist.Add(data);
                    }
                    catch (Exception ex)
                    {
                        // 记录异常信息
                        Trace.WriteLine($"{DateTime.Now.ToLongTimeString()} -- {ex.Message}");
                        continue;
                    }
                }
                // 合计面积
                double totalArea = photolist.Sum(d =>
                {
                    if (double.IsInfinity(d.Area))
                    {
                        return 0d;
                    }
                    return d.Area;
                });
                // 显示结果
                runPhotonum.Text = photolist.Count.ToString();
                runAllArea.Text = totalArea.ToString("N2");
                isRunning = false;
                string msg = $"已扫描了{photolist.Count}张照片，总面积为{totalArea.ToString("F2")}平方米。";
                // 写入日志
                Trace.WriteLine($"{DateTime.Now.ToLongTimeString()} -- {msg}");
                // 语音朗读
                Task.Run(() =>
                {
                    using (SpeechSynthesizer symthedizer = new SpeechSynthesizer())
                    {
                        symthedizer.Speak(msg);
                    }
                });
            }
        }

        
    }
}
